Retrieve historical adjusted prices via tidyquant
get_stock_prices.RdDownloads daily adjusted closing prices from Yahoo Finance for one or more ticker symbols over a given date range.
Usage
get_stock_prices(tickers, from, to = Sys.Date())Examples
if (FALSE) { # \dontrun{
get_stock_prices(c("AAPL", "MSFT"), from = "2023-01-01")
} # }