Skip to contents

Renders a parameterised R Markdown report from inst/report_template.Rmd and serves it as a file download. The report is rendered into an isolated temporary directory so the working directory of the Shiny session is not affected.

Usage

mod_download_server(id, inputs_r, perf_r)

Arguments

id

Module namespace id.

inputs_r

Reactive list returned by mod_inputs_server().

perf_r

Reactive tibble returned by mod_outputs_server().

Value

Called for side-effects; returns NULL invisibly.